# pytorch-show 

This is a tool to visualize models directly from py scripts  and it can automatically find all nn.Module in the file


**RUN**

`python main.py -f python_file -i 240 240 -d -n`
![img.png](https://s2.loli.net/2023/06/27/k4psbUREQHlXV2O.png)

![image-20230627194415687](https://s2.loli.net/2023/06/27/ahbLlf6yOZ57KYw.png)